AndMultipleVersionConstraint class

Subtype of MultipleVersionConstraintNode which all constraints items must be matched.

Inheritance
Mixed-in types
Annotations
  • @sealed

Constructors

AndMultipleVersionConstraint([List<VersionConstraintNode>? constraints])
Construct raw data of AndMultipleVersionConstraint with given List of VersionConstraintNode for building a single constraint.

Properties

constraintsItems → int
Get an int of T contains in this MultipleVersionConstraintNode.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

inRange(SemVer version, {bool excludePreRelease = true}) → bool
Check version matches all constraints VersionConstraintNode.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited