VersionConstraintNode class

Smallest entity of VersionConstraintRecord that contains SemVer and VersionConstraintOperator only and enough to uses for giving constraint result.

Mixed-in types
Annotations
  • @sealed

Constructors

VersionConstraintNode({required SemVer affectedVersion, required VersionConstraintOperator constraintOperator})
Construct value of VersionConstraintNode with given affectedVersion and constraintOperator.
factory

Properties

affectedVersion → SemVer
Indicate a version to be affected.
final
constraintOperator → VersionConstraintOperator
An Enum field that repersenting affectedVersion's operator.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traditionalVersionConstraint → String
Print traditional version constraint for this node.
no setter

Methods

inRange(SemVer version, {bool excludePreRelease = true}) → bool
Giving a version that is stastified with this record.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited